import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
const jwt = require('jsonwebtoken');
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
const web = [
  {
    path: '/',
    redirect: '/adminCenter/homeIndex',
  },
  // 管理登录
  {
    path: '/login',
    name: 'login',
    meta: { title: '管理登录' },
    component: () => import('../views/login.vue'),
  },
  // 管理中心
  {
    path: '/adminCenter/homeIndex',
    name: 'adminCenter',
    component: () => import('@common/src/components/admin-frame/Home.vue'),
    children: [
      {
        path: '/adminCenter/homeIndex',
        name: 'admin_homeIndex',
        meta: { title: '首页' },
        component: () => import('../views/adminCenter/homeIndex/index.vue'),
      },
      {
        path: '/user',
        meta: { title: '办案人员' },
        component: () => import('../views/user/index.vue'),
      },
      {
        path: '/user/detail',
        meta: { title: '办案人员' },
        component: () => import('../views/user/detail.vue'),
      },
      {
        path: '/pos',
        meta: { title: '位置信息标记' },
        component: () => import('../views/pos/index.vue'),
      },
      {
        path: '/case/personnel',
        meta: { title: '涉案人员信息' },
        component: () => import('../views/case/personnel/index.vue'),
      },
      {
        path: '/case/cigarette',
        meta: { title: '涉案卷烟信息' },
        component: () => import('../views/case/cigarette/index.vue'),
      },
      {
        path: '/case/illegal',
        meta: { title: '违法情况' },
        component: () => import('../views/case/illegal/index.vue'),
      },
      {
        path: '/group',
        meta: { title: '群组管理' },
        component: () => import('../views/group/index.vue'),
      },
      {
        path: '/system/updatepd',
        meta: { title: '修改密码' },
        component: () => import('../views/system/updatepd/index.vue'),
      },
    ],
  },
];
const routes = [...web];
const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});
router.beforeEach((to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.path == '/adminCenter/homeIndex') {
    if (!token) {
      // next('/login');
      next();
    } else {
      let user = jwt.decode(token);
      store.commit('setUser', user, { root: true });
      next();
    }
  } else {
    let user = jwt.decode(token);
    store.commit('setUser', user, { root: true });
    next();
  }
});

export default router;
